;; Generated package description from timeout.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "timeout" "2.1.6.0.20260504.161229" "Throttle or debounce Elisp functions" '((emacs "24.4")) :commit "b1212984709c4b50c509ef6d3bd959951e5dcc91" :authors '(("Karthik Chikmagalur" . "karthikchikmagalur@gmail.com")) :maintainer '("Karthik Chikmagalur" . "karthikchikmagalur@gmail.com") :keywords '("convenience" "extensions") :url "https://github.com/karthink/timeout")
